| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Matters.Create
Contents
Description
Creates a matter with the given name and description. The initial state is open, and the owner is the method caller. Returns the created matter with default view.
See: Google Vault API Reference for vault.matters.create.
Synopsis
- type VaultMattersCreateResource = "v1" :> ("matters" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Matter :> Post '[JSON] Matter))))))))
- data VaultMattersCreate = VaultMattersCreate {}
- newVaultMattersCreate :: Matter -> VaultMattersCreate
Resource
type VaultMattersCreateResource = "v1" :> ("matters" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Matter :> Post '[JSON] Matter)))))))) Source #
A resource alias for vault.matters.create method which the
VaultMattersCreate request conforms to.
Constructing a Request
data VaultMattersCreate Source #
Creates a matter with the given name and description. The initial state is open, and the owner is the method caller. Returns the created matter with default view.
See: newVaultMattersCreate smart constructor.
Constructors
| VaultMattersCreate | |
Fields
| |
Instances
newVaultMattersCreate Source #
Arguments
| :: Matter | Multipart request metadata. See |
| -> VaultMattersCreate |
Creates a value of VaultMattersCreate with the minimum fields required to make a request.