| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Matters.Holds.Accounts.Delete
Contents
Description
Removes an account from a hold.
See: Google Vault API Reference for vault.matters.holds.accounts.delete.
Synopsis
- type VaultMattersHoldsAccountsDeleteResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("holds" :> (Capture "holdId" Text :> ("accounts" :> (Capture "accountId" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty))))))))))))
- data VaultMattersHoldsAccountsDelete = VaultMattersHoldsAccountsDelete {}
- newVaultMattersHoldsAccountsDelete :: Text -> Text -> Text -> VaultMattersHoldsAccountsDelete
Resource
type VaultMattersHoldsAccountsDeleteResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("holds" :> (Capture "holdId" Text :> ("accounts" :> (Capture "accountId" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty)))))))))))) Source #
A resource alias for vault.matters.holds.accounts.delete method which the
VaultMattersHoldsAccountsDelete request conforms to.
Constructing a Request
data VaultMattersHoldsAccountsDelete Source #
Removes an account from a hold.
See: newVaultMattersHoldsAccountsDelete smart constructor.
Constructors
| VaultMattersHoldsAccountsDelete | |
Fields
| |
Instances
newVaultMattersHoldsAccountsDelete Source #
Arguments
| :: Text | The ID of the account to remove from the hold. See |
| -> Text | The hold ID. See |
| -> Text | The matter ID. See |
| -> VaultMattersHoldsAccountsDelete |
Creates a value of VaultMattersHoldsAccountsDelete with the minimum fields required to make a request.