| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Matters.Holds.Accounts.List
Contents
Description
Lists the accounts covered by a hold. This can list only individually-specified accounts covered by the hold. If the hold covers an organizational unit, use the Admin SDK. to list the members of the organizational unit on hold.
See: Google Vault API Reference for vault.matters.holds.accounts.list.
Synopsis
- type VaultMattersHoldsAccountsListResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("holds" :> (Capture "holdId" Text :> ("accounts" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] ListHeldAccountsResponse)))))))))))
- data VaultMattersHoldsAccountsList = VaultMattersHoldsAccountsList {}
- newVaultMattersHoldsAccountsList :: Text -> Text -> VaultMattersHoldsAccountsList
Resource
type VaultMattersHoldsAccountsListResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("holds" :> (Capture "holdId" Text :> ("accounts" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] ListHeldAccountsResponse))))))))))) Source #
A resource alias for vault.matters.holds.accounts.list method which the
VaultMattersHoldsAccountsList request conforms to.
Constructing a Request
data VaultMattersHoldsAccountsList Source #
Lists the accounts covered by a hold. This can list only individually-specified accounts covered by the hold. If the hold covers an organizational unit, use the Admin SDK. to list the members of the organizational unit on hold.
See: newVaultMattersHoldsAccountsList smart constructor.
Constructors
| VaultMattersHoldsAccountsList | |
Fields
| |
Instances
newVaultMattersHoldsAccountsList Source #
Arguments
| :: Text | The hold ID. See |
| -> Text | The matter ID. See |
| -> VaultMattersHoldsAccountsList |
Creates a value of VaultMattersHoldsAccountsList with the minimum fields required to make a request.