| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Matters.Holds.Delete
Contents
Description
Removes the specified hold and releases the accounts or organizational unit covered by the hold. If the data is not preserved by another hold or retention rule, it might be purged.
See: Google Vault API Reference for vault.matters.holds.delete.
Synopsis
- type VaultMattersHoldsDeleteResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("holds" :> (Capture "holdId" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty))))))))))
- data VaultMattersHoldsDelete = VaultMattersHoldsDelete {}
- newVaultMattersHoldsDelete :: Text -> Text -> VaultMattersHoldsDelete
Resource
type VaultMattersHoldsDeleteResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("holds" :> (Capture "holdId" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty)))))))))) Source #
A resource alias for vault.matters.holds.delete method which the
VaultMattersHoldsDelete request conforms to.
Constructing a Request
data VaultMattersHoldsDelete Source #
Removes the specified hold and releases the accounts or organizational unit covered by the hold. If the data is not preserved by another hold or retention rule, it might be purged.
See: newVaultMattersHoldsDelete smart constructor.
Constructors
| VaultMattersHoldsDelete | |
Fields
| |
Instances
newVaultMattersHoldsDelete Source #
Arguments
| :: Text | The hold ID. See |
| -> Text | The matter ID. See |
| -> VaultMattersHoldsDelete |
Creates a value of VaultMattersHoldsDelete with the minimum fields required to make a request.