| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Matters.SavedQueries.Delete
Contents
Description
Deletes the specified saved query.
See: Google Vault API Reference for vault.matters.savedQueries.delete.
Synopsis
- type VaultMattersSavedQueriesDeleteResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("savedQueries" :> (Capture "savedQueryId" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty))))))))))
- data VaultMattersSavedQueriesDelete = VaultMattersSavedQueriesDelete {
- xgafv :: Maybe Xgafv
- accessToken :: Maybe Text
- callback :: Maybe Text
- matterId :: Text
- savedQueryId :: Text
- uploadType :: Maybe Text
- uploadProtocol :: Maybe Text
- newVaultMattersSavedQueriesDelete :: Text -> Text -> VaultMattersSavedQueriesDelete
Resource
type VaultMattersSavedQueriesDeleteResource = "v1" :> ("matters" :> (Capture "matterId" Text :> ("savedQueries" :> (Capture "savedQueryId" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty)))))))))) Source #
A resource alias for vault.matters.savedQueries.delete method which the
VaultMattersSavedQueriesDelete request conforms to.
Constructing a Request
data VaultMattersSavedQueriesDelete Source #
Deletes the specified saved query.
See: newVaultMattersSavedQueriesDelete smart constructor.
Constructors
| VaultMattersSavedQueriesDelete | |
Fields
| |
Instances
newVaultMattersSavedQueriesDelete Source #
Arguments
| :: Text | The ID of the matter to delete the saved query from. See |
| -> Text | ID of the saved query to delete. See |
| -> VaultMattersSavedQueriesDelete |
Creates a value of VaultMattersSavedQueriesDelete with the minimum fields required to make a request.