| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Operations.Cancel
Contents
Description
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
See: Google Vault API Reference for vault.operations.cancel.
Synopsis
- type VaultOperationsCancelResource = "v1" :> (CaptureMode "name" "cancel" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] CancelOperationRequest :> Post '[JSON] Empty))))))))
- data VaultOperationsCancel = VaultOperationsCancel {
- xgafv :: Maybe Xgafv
- accessToken :: Maybe Text
- callback :: Maybe Text
- name :: Text
- payload :: CancelOperationRequest
- uploadType :: Maybe Text
- uploadProtocol :: Maybe Text
- newVaultOperationsCancel :: Text -> CancelOperationRequest -> VaultOperationsCancel
Resource
type VaultOperationsCancelResource = "v1" :> (CaptureMode "name" "cancel" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] CancelOperationRequest :> Post '[JSON] Empty)))))))) Source #
A resource alias for vault.operations.cancel method which the
VaultOperationsCancel request conforms to.
Constructing a Request
data VaultOperationsCancel Source #
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
See: newVaultOperationsCancel smart constructor.
Constructors
| VaultOperationsCancel | |
Fields
| |
Instances
newVaultOperationsCancel Source #
Arguments
| :: Text | The name of the operation resource to be cancelled. See |
| -> CancelOperationRequest | Multipart request metadata. See |
| -> VaultOperationsCancel |
Creates a value of VaultOperationsCancel with the minimum fields required to make a request.