| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Operations.Delete
Contents
Description
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
See: Google Vault API Reference for vault.operations.delete.
Synopsis
- type VaultOperationsDeleteResource = "v1" :> (Capture "name" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty)))))))
- data VaultOperationsDelete = VaultOperationsDelete {}
- newVaultOperationsDelete :: Text -> VaultOperationsDelete
Resource
type VaultOperationsDeleteResource = "v1" :> (Capture "name" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Empty))))))) Source #
A resource alias for vault.operations.delete method which the
VaultOperationsDelete request conforms to.
Constructing a Request
data VaultOperationsDelete Source #
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
See: newVaultOperationsDelete smart constructor.
Constructors
| VaultOperationsDelete | |
Fields
| |
Instances
newVaultOperationsDelete Source #
Arguments
| :: Text | The name of the operation resource to be deleted. See |
| -> VaultOperationsDelete |
Creates a value of VaultOperationsDelete with the minimum fields required to make a request.