| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Operations.Get
Contents
Description
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
See: Google Vault API Reference for vault.operations.get.
Synopsis
- type VaultOperationsGetResource = "v1" :> (Capture "name" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] Operation)))))))
- data VaultOperationsGet = VaultOperationsGet {}
- newVaultOperationsGet :: Text -> VaultOperationsGet
Resource
type VaultOperationsGetResource = "v1" :> (Capture "name" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] Operation))))))) Source #
A resource alias for vault.operations.get method which the
VaultOperationsGet request conforms to.
Constructing a Request
data VaultOperationsGet Source #
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
See: newVaultOperationsGet smart constructor.
Constructors
| VaultOperationsGet | |
Fields
| |
Instances
newVaultOperationsGet Source #
Arguments
| :: Text | The name of the operation resource. See |
| -> VaultOperationsGet |
Creates a value of VaultOperationsGet with the minimum fields required to make a request.