| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.Vault.Operations.List
Contents
Description
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
See: Google Vault API Reference for vault.operations.list.
Synopsis
- type VaultOperationsListResource = "v1" :> (Capture "name" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "filter" Text :> (QueryParam "pageSize" Int32 :> (QueryParam "pageToken" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] ListOperationsResponse))))))))))
- data VaultOperationsList = VaultOperationsList {}
- newVaultOperationsList :: Text -> VaultOperationsList
Resource
type VaultOperationsListResource = "v1" :> (Capture "name" Text :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "filter" Text :> (QueryParam "pageSize" Int32 :> (QueryParam "pageToken" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] ListOperationsResponse)))))))))) Source #
A resource alias for vault.operations.list method which the
VaultOperationsList request conforms to.
Constructing a Request
data VaultOperationsList Source #
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
See: newVaultOperationsList smart constructor.
Constructors
| VaultOperationsList | |
Fields
| |
Instances
newVaultOperationsList Source #
Arguments
| :: Text | The name of the operation's parent resource. See |
| -> VaultOperationsList |
Creates a value of VaultOperationsList with the minimum fields required to make a request.